@@ -20,7 +20,7 @@ def get_logger(file_name=None):
 
         # 第二步，创建一个handler，用于写入日志文件
         logfile = os.path.join(log_dir, file_name or 'ChGraphLog.log')
-        fh = TimedRotatingFileHandler(logfile, when='D', interval=1, backupCount=30)
+        fh = TimedRotatingFileHandler(logfile, when='MIDNIGHT', interval=1, backupCount=30)
         fh.setLevel(logging.DEBUG)  # 输出到file的log等级的开关
 
         # 第三步，再创建一个handler，用于输出到控制台
